@@ -15,12 +15,12 @@ use Linux::Event::Fork;
 
 
 my $loop = Linux::Event->new;
-$loop->fork_helper(max_children => ($ENV{MAX} // 4));
+my $forker = Linux::Event::Fork->new($loop, max_children => ($ENV{MAX} // 4));
 
 my $jobs = $ENV{JOBS} // 25;
 
 for my $i (1 .. $jobs) {
-  $loop->fork(
+  $forker->spawn(
     tag => "job:$i",
 
     # A tiny "job" that prints one line and exits.
@@ -38,7 +38,7 @@ for my $i (1 .. $jobs) {
 }
 
 # Wait until the pool is fully idle (running==0 && queued==0) then stop the loop.
-$loop->fork_helper->drain(on_done => sub ($fork) {
+$forker->drain(on_done => sub ($fork) {
   print "DONE (all jobs finished)\n";
   $loop->stop;
 });
