@@ -17,8 +17,9 @@ use Linux::Event;
 use Linux::Event::Fork;
 
 my $loop = Linux::Event->new;
+my $forker = Linux::Event::Fork->new($loop);
 
-$loop->fork(
+$forker->spawn(
   tag => 'child-callback',
 
   child => sub {
