@@ -27,8 +27,9 @@ use Linux::Event;
 use Linux::Event::Fork;
 
 my $loop = Linux::Event->new;
+my $forker = Linux::Event::Fork->new($loop);
 
-$loop->fork(
+$forker->spawn(
   tag => 'chunk-demo',
 
   cmd => [ $^X, '-we', q{ print "line1
