@@ -3,7 +3,7 @@ use v5.36;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Carp qw(croak);
 use POSIX ();
@@ -12,53 +12,9 @@ use Fcntl qw(F_GETFL F_SETFL O_NONBLOCK);
 use Linux::Event::Fork::Child ();
 use Linux::Event::Fork::Request ();
 
-sub import ($class, %import) {
-  croak 'import-time options are not supported; configure at runtime via $loop->fork_helper(...)' if %import;
-my $loop_pkg = 'Linux::Event::Loop';
 
-  no strict 'refs';
-
-  # If called again with no options, don't clobber existing installed methods.
-  if (!%import && defined &{"${loop_pkg}::fork"}) {
-    # Still ensure fork_helper exists below.
-  } else {
-    *{"${loop_pkg}::fork"} = sub ($loop, %args) {
-      my $fork = $loop->{_linux_event_fork} ||= $class->new(loop => $loop, %import);
-      return $fork->_spawn(%args) if $fork->can('_spawn');
-      return $fork->_spawn(%args);
-    };
-  }
-
-  *{"${loop_pkg}::fork_helper"} = sub ($loop, %args) {
-  # Return the per-loop helper (create on first use).
-  my $fork = $loop->{_linux_event_fork};
-
-  if (!$fork) {
-    $fork = $loop->{_linux_event_fork} = $class->new(loop => $loop, %import, %args);
-    return $fork;
-  }
-
-  # Allow runtime reconfiguration (currently only max_children).
-  if (%args) {
-    my $max_children = delete $args{max_children};
-    if (defined $max_children) {
-      $max_children = 0 if !defined $max_children;
-      croak "max_children must be a non-negative integer" if $max_children !~ /^\\d+$/;
-      $fork->{max_children} = 0 + $max_children;
-    }
-    croak "unknown args: " . join(", ", sort keys %args) if %args;
-  }
-
-  return $fork;
-};
-
-
-  return;
-}
-
-sub new ($class, %args) {
-  my $loop = delete $args{loop};
-  croak "loop is required" if !$loop;
+sub new ($class, $loop, %args) {
+  croak "loop is required" if !$loop || !ref($loop);
 
   my $max_children = delete $args{max_children};
   $max_children = 0 if !defined $max_children;
@@ -74,12 +30,31 @@ sub new ($class, %args) {
   }, $class;
 }
 
-sub loop ($self) { return $self->{loop} }
-sub max_children ($self) { return $self->{max_children} }
-sub running ($self) { return $self->{running} }
-sub queued ($self) { return scalar @{ $self->{queue} } }
+sub loop ($self)    {return $self->{loop} }
+sub running ($self) {return $self->{running} }
+sub queued ($self)  {return scalar @{ $self->{queue} } }
 
-sub _spawn ($self, %spec) {
+sub max_children ($self, $new = undef) {
+  if (defined $new) {
+    croak "max_children must be a non-negative integer"
+      if $new !~ /^\d+$/;
+
+    $self->{max_children} = 0 + $new;
+
+    # If we increased the limit, try to start queued work.
+    while ($self->{max_children} && $self->{running} < $self->{max_children}) {
+      my $req = shift @{ $self->{queue} } or last;
+      next if $req->_canceled;
+      $req->_start;
+    }
+
+    $self->_maybe_fire_drain;
+  }
+
+  return $self->{max_children};
+}
+
+sub spawn ($self, %spec) {
   # Controlled parallelism: if max_children is set and we are at capacity,
   # enqueue the request and return a Request handle.
   if ($self->{max_children} && $self->{running} >= $self->{max_children}) {
@@ -363,7 +338,7 @@ __END__
 
 =head1 NAME
 
-Linux::Event::Fork - Asynchronous child process management for Linux::Event
+Linux::Event::Fork - Child process management integrated with Linux::Event
 
 =head1 SYNOPSIS
 
@@ -371,235 +346,301 @@ Linux::Event::Fork - Asynchronous child process management for Linux::Event
   use Linux::Event;
   use Linux::Event::Fork;
 
-  my $loop = Linux::Event->new;
-
-  # Configure at runtime (Option A)
-  my $fork = $loop->fork_helper(
-    max_children => 4,
+  my $loop   = Linux::Event->new;
+  my $forker = Linux::Event::Fork->new($loop,
+    max_children => 4,  # 0 = unlimited
   );
 
-  $loop->fork(
+  my $h = $forker->spawn(
     cmd => [ $^X, '-we', 'print "hello\n"; exit 0' ],
 
     on_stdout => sub ($child, $chunk) {
-      # Runs in the parent, inside the event loop.
       print $chunk;
     },
 
     on_exit => sub ($child, $exit) {
-      # Runs in the parent when the child has fully exited.
+      printf "pid=%d exited=%d code=%d\n",
+        $exit->pid, $exit->exited, ($exit->exited ? $exit->code : -1);
       $loop->stop;
     },
   );
 
+  if ($h->isa('Linux::Event::Fork::Request')) {
+    warn "queued\n";
+  }
+
   $loop->run;
 
 =head1 DESCRIPTION
 
-Linux::Event::Fork provides event-loop-integrated child process
-management with:
+Linux::Event::Fork runs child processes while integrating their lifecycle and
+I/O streams (stdout/stderr/stdin) with a L<Linux::Event> loop.
+
+Features:
 
 =over 4
 
 =item *
-Nonblocking stdout/stderr capture
+Nonblocking stdout/stderr capture (chunk callbacks)
 
 =item *
-Streaming stdin (parent -> child)
+Optional streaming stdin (parent -> child)
 
 =item *
-Timeout support with optional TERM escalation
+Timeout support with optional escalation to SIGKILL
 
 =item *
-Bounded parallelism (max_children)
+Bounded parallelism (max_children) with queueing
 
 =item *
-Queueing and drain semantics
+Drain callback when all work completes
 
 =item *
-Cancel queued requests
+Cancel queued requests (bulk or per-request)
 
 =item *
-Introspection (running, queued)
+Introspection (running/queued/max_children)
 
 =back
 
 =head1 EXECUTION MODEL
 
-All C<on_*> callbacks run in the B<parent process>,
-inside the B<Linux::Event event loop thread>.
+All C<on_*> callbacks run in the B<parent process>, inside the event loop.
 
-Only the C<child => sub { ... }> callback runs in the child process.
+Only the C<child =E<gt> sub { ... }> callback runs in the B<child process>.
 
-Execution boundary:
+Stream directions:
 
-    parent process
-    ----------------------------
-        $loop->fork(...)
-            |
-            | fork()
-            v
-    child process
-    ----------------------------
-        child => sub { ... }
-        or
-        exec(@cmd)
+  stdin   : parent -> child
+  stdout  : child  -> parent
+  stderr  : child  -> parent
 
-Callbacks:
-
-    child stdout/stderr  --->  parent (on_stdout / on_stderr)
-    child exit           --->  parent (on_exit)
-    timeout event        --->  parent (on_timeout)
-
-=head1 STREAM DIRECTIONS
-
-Stream direction is explicit:
-
-    stdin   : parent ---> child
-    stdout  : child  ---> parent
-    stderr  : child  ---> parent
-
-There is no "on_stdin" for receiving data.
-Use C<on_stdout> or C<on_stderr> to receive child output.
-
-=head1 LIFECYCLE
-
-Normal execution:
-
-    fork()
-      |
-      +--> running
-              |
-              +--> stdout/stderr events
-              |
-              +--> exit
-                      |
-                      +--> on_exit callback
-
-Queueing:
-
-    running < max_children
-        |
-        +--> start immediately
-
-    running >= max_children
-        |
-        +--> return Request object
-        +--> queued
-        +--> auto-start when capacity frees
-
-Drain fires when:
-
-    running == 0
-    AND
-    queue is empty
-
-=head1 TIMEOUT AND ESCALATION
-
-If C<timeout> is set:
-
-    timeout expires
-        |
-        +--> on_timeout (parent)
-        +--> SIGTERM sent to child
-
-If C<timeout_kill> is also set:
-
-    timeout expires
-        |
-        +--> SIGTERM
-        |
-        +--> wait timeout_kill seconds
-        |
-        +--> if still alive -> SIGKILL
-
-Timeline:
-
-    |---- timeout ----|---- timeout_kill ----|
-    fork              TERM                  KILL
+There is no "on_stdin" callback. Stdin is a write stream to the child.
 
 =head1 CONSTRUCTOR
 
-=head2 new
+=head2 new($loop, %args)
 
-  my $fork = Linux::Event::Fork->new(
-    loop         => $loop,        # required
-    max_children => 4,            # optional
+  my $forker = Linux::Event::Fork->new($loop,
+    max_children => 4,   # optional (default 0 = unlimited)
   );
 
-Low-level constructor.
+Constructs a forker bound to a specific event loop.
 
-Users should normally call:
+Arguments:
 
-  $loop->fork_helper(...)
+=over 4
 
-instead.
+=item max_children => $n
 
-=head1 LOOP METHODS
+Maximum number of concurrently running children. C<0> means unlimited.
 
-=head2 $loop->fork_helper(%opts)
+=back
 
-Installs or returns the per-loop helper.
+=head1 METHODS
 
-Options:
+=head2 loop
 
-  max_children => $non_negative_integer
+  my $loop = $forker->loop;
 
-Configuration is runtime-only.
+Returns the underlying L<Linux::Event> loop.
 
-Import-time options are not supported.
+=head2 spawn(%spec)
 
-=head2 $loop->fork(%args)
+  my $h = $forker->spawn(%spec);
 
-Spawn a child or queue a request.
+Starts a child immediately if capacity allows, otherwise enqueues the request.
 
-Returns:
+Returns either:
 
-  Linux::Event::Fork::Child   (started immediately)
-  Linux::Event::Fork::Request (queued)
+=over 4
 
-=head1 fork() OPTIONS
+=item * L<Linux::Event::Fork::Child>
+
+If started immediately.
+
+=item * L<Linux::Event::Fork::Request>
+
+If queued due to C<max_children>.
+
+=back
+
+=head3 spawn options
 
 Exactly one of:
 
-  cmd   => [ @argv ]
-  child => sub { ... }
+=over 4
 
-Optional keys:
+=item cmd => \@argv
 
-  tag        => $string
-  data       => $any_scalar
+Execs the given argv in the child.
 
-  on_stdout  => sub ($child, $chunk) { ... }
-      Runs in parent when child writes to stdout.
+=item child => sub { ... }
 
-  on_stderr  => sub ($child, $chunk) { ... }
-      Runs in parent when child writes to stderr.
+Runs the coderef in the child process. If it returns, the child exits with 127.
 
-  on_exit    => sub ($child, $exit) { ... }
-      Runs in parent after child has fully exited.
+=back
 
-  timeout        => $seconds
-      Soft timeout in seconds.
+Optional:
 
-  on_timeout     => sub ($child) { ... }
-      Runs in parent when timeout fires.
+=over 4
 
-  timeout_kill   => $seconds
-      Escalation delay before SIGKILL.
+=item on_start => sub ($child) { ... }
 
-=head1 INTROSPECTION
+Called in the parent after the child handle is created (and before the loop
+has necessarily observed any I/O).
 
-  $fork->running
-  $fork->queued
-  $fork->max_children
+=item on_stdout => sub ($child, $chunk) { ... }
+
+Called in the parent when the child writes to stdout.
+
+=item on_stderr => sub ($child, $chunk) { ... }
+
+Called in the parent when the child writes to stderr.
+
+=item on_exit => sub ($child, $exit) { ... }
+
+Called in the parent after the child has fully exited. C<$exit> is a
+L<Linux::Event::Fork::Exit>.
+
+=item capture_stdout => $bool
+
+Force stdout capture on/off.
+Default: true if C<on_stdout> is provided, otherwise false.
+
+=item capture_stderr => $bool
+
+Force stderr capture on/off.
+Default: true if C<on_stderr> is provided, otherwise false.
+
+=item stdin => $string
+
+If provided, writes this string to the child's stdin after start.
+
+=item stdin_pipe => $bool
+
+If true, keeps stdin open for streaming writes using the child handle.
+If false (default), stdin is closed after the initial C<stdin> write (if any).
+
+=item timeout => $seconds
+
+Soft timeout. When it fires: calls C<on_timeout> (if any) and sends SIGTERM.
+
+=item on_timeout => sub ($child) { ... }
+
+Called in the parent when C<timeout> fires.
+
+=item timeout_kill => $seconds
+
+If set, after SIGTERM waits this many seconds and then sends SIGKILL if still alive.
+
+=item cwd => $dir
+
+Changes working directory in the child before exec/callback.
+
+=item umask => $mask
+
+Sets umask in the child before exec/callback.
+
+=item clear_env => $bool
+
+If true, clears %ENV in the child before applying C<env>.
+
+=item env => \%env
+
+Merges these variables into %ENV in the child before exec/callback.
+
+=item tag => $string
+
+Opaque tag stored on the child/request handles.
+
+=item data => $scalar
+
+Opaque user data stored on the child/request handles.
+
+=back
+
+=head2 max_children([$n])
+
+  my $n = $forker->max_children;
+  $forker->max_children(8);
+
+Get or set the concurrency limit.
+
+C<0> means unlimited.
+
+Increasing the limit may immediately start queued requests.
+Decreasing the limit does not affect running children; it only limits future starts.
+
+=head2 running
+
+  my $n = $forker->running;
+
+Number of children currently running (tracked for capacity control).
+
+=head2 queued
+
+  my $n = $forker->queued;
+
+Number of queued requests waiting for capacity.
+
+=head2 drain(on_done => sub ($forker) { ... })
+
+  $forker->drain(on_done => sub ($forker) {
+    ...
+  });
+
+Registers a callback that fires once when:
+
+  running == 0
+  AND
+  queue is empty
+
+If already drained at registration time, the callback fires immediately on the
+next opportunity inside the loop.
+
+=head2 cancel_queued([$predicate])
+
+  my $n = $forker->cancel_queued;
+  my $n = $forker->cancel_queued(sub ($req) { ... });
+
+Cancels queued requests. If a predicate is provided, only queued requests for which
+the predicate returns true are canceled.
+
+Returns the number canceled.
+
+=head1 RETURN OBJECTS
+
+=head2 Linux::Event::Fork::Child
+
+Represents a running (or exited) child process.
+
+See L<Linux::Event::Fork::Child>.
+
+=head2 Linux::Event::Fork::Request
+
+Represents a queued spawn request that has not yet started.
+
+See L<Linux::Event::Fork::Request>.
+
+=head1 CAPACITY AND QUEUE MODEL
+
+When C<max_children> is non-zero:
+
+  running < max_children   -> spawn immediately (Child)
+  running >= max_children  -> enqueue (Request)
+
+When a child exits, capacity is released and queued requests start FIFO.
+
+Changing C<max_children> at runtime affects future starts, and increasing the limit
+may immediately start queued requests.
 
 =head1 WHAT THIS MODULE IS NOT
 
 This is not a supervisor, scheduler, or promise framework.
 
-It is a deterministic process management layer
-built directly on Linux::Event.
+It is a deterministic process management layer for child processes built directly
+on Linux::Event.
 
 =head1 AUTHOR
 
